@@ -1,5 +1,7 @@
+from typing import Tuple
+
 from django.contrib import admin
-from edc_model_admin import audit_fieldset_tuple
+from django_audit_fields.admin import audit_fieldset_tuple
 
 from ..admin_site import edc_pharmacy_admin
 from ..forms import MedicationForm
@@ -22,6 +24,8 @@ class MedicationAdmin(ModelAdminMixin, admin.ModelAdmin):
         audit_fieldset_tuple,
     )
 
-    list_display = ["name", "display_name", "created", "modified"]
-    search_fields = ["name"]
-    ordering = ["name"]
+    list_display: Tuple[str, ...] = ("name", "display_name", "created", "modified")
+
+    search_fields: Tuple[str, ...] = ("name",)
+
+    ordering: Tuple[str, ...] = ("name",)
